@@ -1,6 +1,6 @@
 package Message::Passing::Filter::All;
-use Moose;
-use namespace::autoclean;
+use Moo;
+use namespace::clean -except => 'meta';
 
 with 'Message::Passing::Role::Filter';
 
@@ -8,7 +8,7 @@ sub filter {
     return;
 }
 
-__PACKAGE__->meta->make_immutable;
+
 1;
 
 =head1 NAME
